from typing import Optional, List

from pydantic import BaseModel, Field

from mediaApiClient.content_meta_models import ContentMeta


class LightWeightCompilation(BaseModel):
    id: str
    title: str
    description: str
    provider: str
    tags: Optional[List[str]] = None
    contentIds: Optional[List[str]] = None


class CompilationRequest(BaseModel):
    title: Optional[str] = None
    description: Optional[str] = None
    provider: Optional[str] = None
    tags: Optional[List[str]] = None
    contentIds: Optional[List[str]] = None


class CompilationWithContents(BaseModel):
    id: str
    title: str
    description: str
    provider: str
    tags: Optional[List[str]] = None
    contents: Optional[List[ContentMeta]] = None


class PageCompilationWithContents(CompilationWithContents):
    number: Optional[int] = Field(..., alias="number")
    size: Optional[int] = Field(..., alias="size")
    total_pages: Optional[int] = Field(..., alias="totalPages")
    total_elements: Optional[int] = Field(..., alias="totalElements")
    next: Optional[bool] = Field(..., alias="hasNext")
    previous: Optional[bool] = Field(..., alias="hasPrevious")



from datetime import datetime
from enum import Enum
from typing import Optional, List

from pydantic import BaseModel, constr
from mediaApiClient.services_models import LightWeightService


class EUserStatus(Enum):
    ACTIVE = "ACTIVE"
    REMOVED = "REMOVED"


class UserStatus(BaseModel):
    id: int
    title: str
    description: Optional[str] = None


class LightWeightAccount(BaseModel):
    id: int
    accountId: str
    status: UserStatus
    created: datetime
    services: Optional[List[str]] = None


class AccountFullInfo(BaseModel):
    accountId: str
    connectedServices: Optional[List[LightWeightService]] = None


class AccountToCreate(BaseModel):
    accountId: constr(strip_whitespace=True, min_length=1)
    servicesIds: List[int]



from typing import List

import requests

from mediaApiClient.services_models import LightWeightService


class ClientServiceControllerV1:
    def __init__(self, base_url, auth_token):
        self.base_url = base_url
        self.auth_token = auth_token

    def get_services(self):
        url = f"{self.base_url}/api/v1/services"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            services_data = response.json()
            return [LightWeightService(**service) for service in services_data]
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")




from typing import List

import requests

from mediaApiClient.account_models import LightWeightAccount, AccountFullInfo, AccountToCreate


class ClientAccountControllerV1:
    ACCOUNT_URL = "/api/v1/accounts"

    def __init__(self, base_url, auth_token):
        self.base_url = base_url
        self.auth_token = auth_token

    def get_all_accounts(self):
        url = f"{self.base_url}{self.ACCOUNT_URL}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            account_data = response.json()
            return [LightWeightAccount(**account) for account in account_data]
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def get_account_by_id(self, account_id):
        url = f"{self.base_url}{self.ACCOUNT_URL}/{account_id}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            account_data = response.json()
            return AccountFullInfo(**account_data)
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def create_account_by_request(self, account_to_create: AccountToCreate):
        payload = account_to_create.model_dump_json()
        url = f"{self.base_url}{self.ACCOUNT_URL}"

        headers = {
            "Authorization-Client": self.auth_token,
            "Content-Type": "application/json"
        }

        response = requests.post(url, headers=headers, data=payload)

        if response.status_code == 201:
            account_data = response.json()
            return AccountFullInfo(**account_data)
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def delete_account_by_id(self, account_id):
        url = f"{self.base_url}{self.ACCOUNT_URL}/{account_id}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.delete(url, headers=headers)

        if response.status_code != 204:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def add_service_for_account(self, account_id, service_id):
        url = f"{self.base_url}{self.ACCOUNT_URL}/{account_id}/services/{service_id}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.patch(url, headers=headers)

        if response.status_code != 200:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def disable_service_for_account(self, account_id, service_id):
        url = f"{self.base_url}{self.ACCOUNT_URL}/{account_id}/services/{service_id}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.delete(url, headers=headers)

        if response.status_code != 204:
            raise Exception(f"Request failed with status code: {response.status_code}")




from mediaApiClient.client_stream_controller_v2 import *
from mediaApiClient.client_content_controller_v2 import *
from mediaApiClient.client_account_controller_v1 import *
from mediaApiClient.client_compilation_controller_v2 import *
from mediaApiClient.client_service_controller_v1 import *
from mediaApiClient.stream_models import *
from mediaApiClient.content_reuest_models import *
from mediaApiClient.content_meta_models import *
from mediaApiClient.account_models import *
from mediaApiClient.compilation_models import *
from mediaApiClient.services_models import *



from typing import List, Optional
from pydantic import BaseModel


class LightWeightService(BaseModel):
    id: Optional[int] = None
    name: Optional[str] = None
    description: Optional[str] = None



from typing import List

import requests

from mediaApiClient.compilation_models import LightWeightCompilation, PageCompilationWithContents, \
    CompilationRequest


class ClientCompilationControllerV2:
    COMPILATION_URL = "/api/v2/compilations"

    def __init__(self, base_url, auth_token):
        self.base_url = base_url
        self.auth_token = auth_token

    def get_all_compilations(self):
        url = f"{self.base_url}{self.COMPILATION_URL}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        response = requests.get(url, headers=headers)

        if response.status_code == 200:
            compilation_data = response.json()
            return [LightWeightCompilation(**compilation) for compilation in compilation_data]
        else:
            raise Exception(f"Request failed with status code: {response.status_code}")

    def get_full_compilation_by_id(self, compilation_id, number=0, size=10):
        url = f"{self.base_url}{self.COMPILATION_URL}/{compilation_id}"
        params = {
            "number": number,
            "size": size
        }

        headers = {
            "Authorization-Client": self.auth_token
        }

        content_response = requests.get(url, params=params, headers=headers)
        if content_response.status_code == 200:
            return PageCompilationWithContents(**content_response.json())
        else:
            raise Exception(f"Request failed with status code: {content_response.status_code}")

    def update_compilation_by_id(self, compilation_id, update_compilation_request: CompilationRequest):
        url = f"{self.base_url}{self.COMPILATION_URL}/{compilation_id}"

        json = update_compilation_request.model_dump_json()

        headers = {
            "Authorization-Client": self.auth_token,
            "Content-Type": "application/json"
        }

        content_response = requests.put(url, headers=headers, data=json)
        if content_response.status_code == 200:
            return LightWeightCompilation(**content_response.json())
        else:
            raise Exception(f"Request failed with status code: {content_response.status_code}")

    def delete_compilation_by_id(self, compilation_id):
        url = f"{self.base_url}{self.COMPILATION_URL}/{compilation_id}"

        headers = {
            "Authorization-Client": self.auth_token
        }

        content_response = requests.delete(url, headers=headers)
        if content_response.status_code != 200:
            raise Exception(f"Request failed with status code: {content_response.status_code}")

    def create_compilation(self, create_compilation_request: CompilationRequest):
        url = f"{self.base_url}{self.COMPILATION_URL}"

        json = create_compilation_request.model_dump_json()

        headers = {
            "Authorization-Client": self.auth_token,
            "Content-Type": "application/json"
        }

        content_response = requests.post(url, headers=headers, data=json)
        if content_response.status_code == 200:
            return LightWeightCompilation(**content_response.json())
        else:
            raise Exception(f"Request failed with status code: {content_response.status_code}")
